﻿using SchoolScheduleContracts.BindingModels;
using SchoolScheduleContracts.BusinessLogicsContracts;
using SchoolScheduleContracts.SearchModels;
using SchoolScheduleContracts.ViewModels;
using SchoolScheduleDataModels.Models;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SchoolSchedule
{
	public partial class GradeForm : Form
	{
		private readonly ITeacherLogic _logicT;
		private readonly IGradeLogic _logicG;
		private int? _id;
		public int Id { set { _id = value; } }


		public GradeForm(ITeacherLogic logicT, IGradeLogic logicG)
		{
			InitializeComponent();
			_logicT = logicT;
			_logicG = logicG;
		}

		private void GradeForm_Load(object sender, EventArgs e)
		{
			try
			{
				var list = _logicT.ReadList(null);
				if (list != null)
				{
					comboBox1.DisplayMember = "FullName";
					comboBox1.ValueMember = "Id";
					comboBox1.DataSource = list;
					comboBox1.SelectedItem = null;
				}
				if (_id.HasValue)
				{
					var dbind = _logicG.ReadElement(new GradeSearchModel { Id = _id });
					for (int i = 0; i < comboBox1.Items.Count; i++)
					{
						if (list[i].Id == dbind.TeacherId)
							comboBox1.SelectedIndex = i;
					}
					textBox1.Text = dbind.Letter.ToString();
					textBox2.Text = dbind.Year.ToString();
				}
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}
		}

		private void button1_Click(object sender, EventArgs e)
		{

			if (string.IsNullOrEmpty(textBox1.Text))
			{
				MessageBox.Show("Заполните поле Буква", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			if (textBox1.Text.Length > 1 || !(textBox1.Text[0] >= 'A' && textBox1.Text[0] <= 'Z'))
			{
				MessageBox.Show("Поле буква должно быть одной заглавной буквой латинского алфавита", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			if (string.IsNullOrEmpty(textBox2.Text))
			{
				MessageBox.Show("Заполните поле Год", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			if (comboBox1.SelectedValue == null)
			{
				MessageBox.Show("Выберите классного руководителя", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			try
			{
				int year = int.Parse(textBox2.Text);
				if (!(year >= 1 && year <= 11))
				{
					throw new Exception("Ошибка при создании заказа. Год должен быть числом от 1 до 11");
				}
				GradeBindingModel model = new GradeBindingModel
				{
					Id = (_id.HasValue ? _id.Value : 0),
					TeacherId = Convert.ToInt32(comboBox1.SelectedValue),
					Letter = textBox1.Text[0],
					Year = year,
				};
				var operationResult = (_id.HasValue ? _logicG.Update(model) : _logicG.Create(model));
				if (!operationResult)
				{
					throw new Exception("Ошибка при создании заказа.");
				}
				MessageBox.Show("Сохранение прошло успешно", "Сообщение",
			   MessageBoxButtons.OK, MessageBoxIcon.Information);
				DialogResult = DialogResult.OK;
				Close();
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}

		}

		private void button2_Click(object sender, EventArgs e)
		{
			DialogResult = DialogResult.Cancel;
			Close();

		}
	}
}
