﻿using SchoolScheduleContracts.BindingModels;
using SchoolScheduleContracts.BusinessLogicsContracts;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SchoolSchedule
{
	public partial class GradesForm : Form
	{
		private readonly IGradeLogic _logic;

		public GradesForm(IGradeLogic logic)
		{
			InitializeComponent();
			_logic = logic;
		}

		private void GradesForm_Load(object sender, EventArgs e)
		{
			LoadData();
		}

		private void LoadData()
		{
			try
			{
				var list = _logic.ReadList(null);
				if (list != null)
				{
					dataGridView1.DataSource = list;
					dataGridView1.Columns["Id"].Visible = false;
					dataGridView1.Columns["TeacherId"].Visible = false;
					dataGridView1.Columns["Year"].AutoSizeMode =
DataGridViewAutoSizeColumnMode.Fill;
					dataGridView1.Columns["Letter"].AutoSizeMode =
DataGridViewAutoSizeColumnMode.Fill;
					dataGridView1.Columns["TeacherFullName"].AutoSizeMode =
DataGridViewAutoSizeColumnMode.Fill;
				}
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}
		}

		private void AddButton_Click(object sender, EventArgs e)
		{
			var service =
Program.ServiceProvider?.GetService(typeof(GradeForm));
			if (service is GradeForm form)
			{
				if (form.ShowDialog() == DialogResult.OK)
				{
					LoadData();
				}
			}

		}

		private void ChangeButton_Click(object sender, EventArgs e)
		{
			if (dataGridView1.SelectedRows.Count == 1)
			{
				var service =
			   Program.ServiceProvider?.GetService(typeof(GradeForm));
				if (service is GradeForm form)
				{
					form.Id =
				   Convert.ToInt32(dataGridView1.SelectedRows[0].Cells["Id"].Value);
					if (form.ShowDialog() == DialogResult.OK)
					{
						LoadData();
					}
				}
			}
		}

		private void DeleteButton_Click(object sender, EventArgs e)
		{
			if (dataGridView1.SelectedRows.Count == 1)
			{
				if (MessageBox.Show("Удалить запись?", "Вопрос",
			   MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
				{
					int id =
				   Convert.ToInt32(dataGridView1.SelectedRows[0].Cells["Id"].Value);
					try
					{
						if (!_logic.Delete(new GradeBindingModel
						{
							Id = id
						}))
						{
							throw new Exception("Ошибка при удалении.");
					    }
						LoadData();
					}
					catch (Exception ex)
					{
						MessageBox.Show(ex.Message, "Ошибка",
					   MessageBoxButtons.OK, MessageBoxIcon.Error);
					}
				}
			}
		}

		private void RefreshButton_Click(object sender, EventArgs e)
		{
			LoadData();
		}
	}
}
