﻿using SchoolScheduleContracts.BindingModels;
using SchoolScheduleContracts.BusinessLogicsContracts;
using SchoolScheduleContracts.SearchModels;
using SchoolScheduleDataBaseImplement.Models;
using SchoolScheduleDataModels.Enums;
using SchoolScheduleDataModels.Models;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using static System.Windows.Forms.VisualStyles.VisualStyleElement;

namespace SchoolSchedule
{
	public partial class LessonCreateForm : Form
	{
		private readonly ISubjectLogic _logicS;
		private readonly IStudentLogic _logicSt;
		private readonly IGradeLogic _logicG;
		private readonly ITeacherLogic _logicT;
		private readonly ISchedulePlaceLogic _logicD;
		private readonly ILessonLogic _logicL;
		private int? _id;
		public int Id { set { _id = value; } }
		public LessonCreateForm(ISubjectLogic logicS, IGradeLogic logicG, ITeacherLogic logicT, ISchedulePlaceLogic logicD, ILessonLogic logicL, IStudentLogic logicSt)
		{
			_logicS = logicS;
			_logicG = logicG;
			_logicT = logicT;
			_logicD = logicD;
			_logicL = logicL;
			_logicSt = logicSt;
			InitializeComponent();
		}

		private void LessonCreateForm_Load(object sender, EventArgs e)
		{
			try
			{
				var listG = _logicG.ReadList(null);
				if (listG != null)
				{
					gradeCombo.DisplayMember = "FullName";
					gradeCombo.ValueMember = "Id";
					gradeCombo.DataSource = listG;
					gradeCombo.SelectedItem = null;
				}
				var listT = _logicT.ReadList(null);
				if (listT != null)
				{
					teacherCombo.DisplayMember = "FullName";
					teacherCombo.ValueMember = "Id";
					teacherCombo.DataSource = listT;
					teacherCombo.SelectedItem = null;
				}
				var listS = _logicS.ReadList(null);
				if (listT != null)
				{
					subjectCombo.DisplayMember = "SubjectName";
					subjectCombo.ValueMember = "Id";
					subjectCombo.DataSource = listS;
					subjectCombo.SelectedItem = null;
				}
				var listD = _logicD.ReadList(null);
				if (listT != null)
				{
					timeCombo.DisplayMember = "Time";
					timeCombo.ValueMember = "Id";
					timeCombo.DataSource = listD;
					timeCombo.SelectedItem = null;
				}
				if (_id.HasValue)
				{
					if (_id.HasValue)
					{
						var dbind = _logicL.ReadElement(new LessonSearchModel { Id = _id });
						for (int i = 0; i < gradeCombo.Items.Count; i++)
						{
							if (listG[i].Id == dbind.GradeId)
								gradeCombo.SelectedIndex = i;
						}
						for (int i = 0; i < subjectCombo.Items.Count; i++)
						{
							if (listS[i].Id == dbind.SubjectId)
								subjectCombo.SelectedIndex = i;
						}

						for (int i = 0; i < teacherCombo.Items.Count; i++)
						{
							if (listT[i].Id == dbind.GradeId)
								teacherCombo.SelectedIndex = i;
						}

						for (int i = 0; i < timeCombo.Items.Count; i++)
						{
							if (listD[i].Id == dbind.SchedulePlaceId)
								timeCombo.SelectedIndex = i;
						}


						homeworkBox.Text = dbind.Homework;
						dateTimePicker1.Value = dbind.Date.ToDateTime(TimeOnly.Parse("00:00 AM"));
					}
				}
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}
		}

		private void AddButton_Click(object sender, EventArgs e)
		{
			if (gradeCombo.SelectedValue == null)
			{
				MessageBox.Show("Выберите класс", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			if (subjectCombo.SelectedValue == null)
			{
				MessageBox.Show("Выберите предмет", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			if (timeCombo.SelectedValue == null)
			{
				MessageBox.Show("Выберите Время", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			if (teacherCombo.SelectedValue == null)
			{
				MessageBox.Show("Выберите учителя", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			try
			{
				LessonBindingModel model = new LessonBindingModel
				{
					Id = (_id.HasValue ? _id.Value : 0),
					GradeId = Convert.ToInt32(gradeCombo.SelectedValue),
					TeacherId = Convert.ToInt32(teacherCombo.SelectedValue),
					SubjectId = Convert.ToInt32(subjectCombo.SelectedValue),
					SchedulePlaceId = Convert.ToInt32(timeCombo.SelectedValue),
					Homework = homeworkBox.Text,
					Date = DateOnly.FromDateTime(dateTimePicker1.Value)
				};
				var operationResult = (_id.HasValue ? _logicL.Update(model) : _logicL.Create(model));
				if (!operationResult)
				{
					throw new Exception("Ошибка при создании занятия.");
				}
				var list = _logicG.GetStudents(new GradeSearchModel { Id = model.GradeId });
				var lst = _logicL.ReadList(null);
				ILessonModel cur = null;
				foreach (var lesson in lst)
				{
					if (lesson.SubjectId == model.SubjectId && lesson.GradeId == model.GradeId && lesson.TeacherId == model.TeacherId &&
						lesson.SchedulePlaceId == model.SchedulePlaceId && lesson.Date == model.Date)
						cur = lesson;
				}
				foreach (var student in list)
				{
					if (student.Attendance.ContainsKey(cur.Id))
						continue;
					student.Attendance[cur.Id] = (cur, StudentStatus.ПР, null);
					_logicSt.Update(new StudentBindingModel
					{
						Id = student.Id,
						FullName = student.FullName,
						GradeId = student.GradeId, 
						Attendance = student.Attendance
					}
					);
				}
				MessageBox.Show("Сохранение прошло успешно", "Сообщение",
			   MessageBoxButtons.OK, MessageBoxIcon.Information);
				DialogResult = DialogResult.OK;
				Close();
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}

		}

		private void CancelButton_Click(object sender, EventArgs e)
		{
			DialogResult = DialogResult.Cancel;
			Close();
		}
	}
}
