﻿using SchoolScheduleContracts.BusinessLogicsContracts;
using SchoolScheduleContracts.SearchModels;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SchoolSchedule
{
	public partial class LessonsForm : Form
	{
		private readonly ILessonLogic _logic;
		public LessonsForm(ILessonLogic logic)
		{
			_logic = logic;
			InitializeComponent();
		}

		private void LessonsForm_Load(object sender, EventArgs e)
		{
			LoadData();
		}

		private void LoadData()
		{
			try
			{
				var list = _logic.ReadList(null);
				if (list != null)
				{
					dataGridView1.DataSource = list;
					dataGridView1.Columns["Id"].Visible = false;
					dataGridView1.Columns["SchedulePlaceId"].Visible = false;
					dataGridView1.Columns["TeacherId"].Visible = false;
					dataGridView1.Columns["SubjectId"].Visible = false;
					dataGridView1.Columns["GradeId"].Visible = false;
					dataGridView1.Columns["Date"].AutoSizeMode =
DataGridViewAutoSizeColumnMode.Fill;
					dataGridView1.Columns["SchedulePlaceTime"].AutoSizeMode =
DataGridViewAutoSizeColumnMode.Fill;
					dataGridView1.Columns["TeacherFullName"].AutoSizeMode =
DataGridViewAutoSizeColumnMode.Fill;
					dataGridView1.Columns["SubjectName"].AutoSizeMode =
DataGridViewAutoSizeColumnMode.Fill;
					dataGridView1.Columns["GradeName"].AutoSizeMode =
DataGridViewAutoSizeColumnMode.Fill;
				}
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}
		}

		private void AddButton_Click(object sender, EventArgs e)
		{
			var service =
Program.ServiceProvider?.GetService(typeof(LessonCreateForm));
			if (service is LessonCreateForm form)
			{
				if (form.ShowDialog() == DialogResult.OK)
				{
					LoadData();
				}
			}
		}

		private void OpenButton_Click(object sender, EventArgs e)
		{
			if (dataGridView1.SelectedRows.Count == 1)
			{
				var service =
			   Program.ServiceProvider?.GetService(typeof(LessonForm));
				if (service is LessonForm form)
				{
					form.Lesson =
				   _logic.ReadElement(new LessonSearchModel { Id = Convert.ToInt32(dataGridView1.SelectedRows[0].Cells["Id"].Value) });
					form.LoadData();
					if (form.ShowDialog() == DialogResult.OK)
					{
						LoadData();
					}
				}
			}
		}
	}
}
