using Microsoft.Extensions.DependencyInjection;
using SchoolScheduleBusinessLogic;
using SchoolScheduleContracts.BusinessLogicsContracts;
using SchoolScheduleContracts.StoragesContracts;
using SchoolScheduleDataBaseImplement.Implements;

namespace SchoolSchedule
{
	internal static class Program
	{
		private static ServiceProvider? _serviceProvider;
		public static ServiceProvider? ServiceProvider => _serviceProvider;
		/// <summary>
		///  The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main()
		{
			ApplicationConfiguration.Initialize();
			var services = new ServiceCollection();
			ConfigureServices(services);
			_serviceProvider = services.BuildServiceProvider();
			Application.Run(_serviceProvider.GetRequiredService<LessonsForm>());

		}
		private static void ConfigureServices(ServiceCollection services)
		{
			services.AddTransient<ISubjectStorage, SubjectStorage>();
			services.AddTransient<ITeacherStorage, TeacherStorage>();
			services.AddTransient<ILessonStorage, LessonStorage>();
			services.AddTransient<IGradeStorage, GradeStorage>();
			services.AddTransient<ISchedulePlaceStorage, SchedulePlaceStorage>();
			services.AddTransient<IStudentStorage, StudentStorage>();
			services.AddTransient<ISubjectLogic, SubjectLogic>();
			services.AddTransient<ITeacherLogic, TeacherLogic>();
			services.AddTransient<IStudentLogic, StudentLogic>();
			services.AddTransient<ISchedulePlaceLogic, SchedulePlaceLogic>();
			services.AddTransient<ILessonLogic, LessonLogic>();
			services.AddTransient<IGradeLogic, GradeLogic>();
			services.AddTransient<SubjectForm>();
			services.AddTransient<SubjectsForm>();
			services.AddTransient<TeacherForm>();
			services.AddTransient<TeachersForm>();
			services.AddTransient<GradeForm>();
			services.AddTransient<GradesForm>();
			services.AddTransient<StudentForm>();
			services.AddTransient<StudentsForm>();
			services.AddTransient<LessonCreateForm>();
			services.AddTransient<LessonsForm>();
			services.AddTransient<LessonForm>();
		}
	}
}