﻿using SchoolScheduleContracts.BindingModels;
using SchoolScheduleContracts.BusinessLogicsContracts;
using SchoolScheduleContracts.SearchModels;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using static System.Windows.Forms.VisualStyles.VisualStyleElement;

namespace SchoolSchedule
{
	public partial class StudentForm : Form
	{
		private readonly IStudentLogic _logicS;
		private readonly IGradeLogic _logicG;
		private int? _id;
		public int Id { set { _id = value; } }
		public StudentForm(IStudentLogic logicS, IGradeLogic logicG)
		{
			InitializeComponent();
			_logicG = logicG;
			_logicS = logicS;
		}

		private void StudentForm_Load(object sender, EventArgs e)
		{
			try
			{
				var list = _logicG.ReadList(null);
				if (list != null)
				{
					comboBox1.DisplayMember = "FullName";
					comboBox1.ValueMember = "Id";
					comboBox1.DataSource = list;
					comboBox1.SelectedItem = null;
				}
				if (_id.HasValue)
				{
					var dbind = _logicS.ReadElement(new StudentSearchModel { Id = _id });
					for (int i = 0; i < comboBox1.Items.Count; i++)
					{
						if (list[i].Id == dbind.GradeId)
							comboBox1.SelectedIndex = i;
					}
					textBox1.Text = dbind.FullName.ToString();
				}
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}
		}

		private void AddButton_Click(object sender, EventArgs e)
		{
			if (string.IsNullOrEmpty(textBox1.Text))
			{
				MessageBox.Show("Заполните поле Фио", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			if (comboBox1.SelectedValue == null)
			{
				MessageBox.Show("Выберите класс", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			try
			{
				StudentBindingModel model = new StudentBindingModel
				{
					Id = (_id.HasValue ? _id.Value : 0),
					FullName = textBox1.Text,
					GradeId = Convert.ToInt32(comboBox1.SelectedValue),
				};
				var operationResult = (_id.HasValue ? _logicS.Update(model) : _logicS.Create(model));
				if (!operationResult)
				{
					throw new Exception("Ошибка при создании ученика.");
				}
				MessageBox.Show("Сохранение прошло успешно", "Сообщение",
			   MessageBoxButtons.OK, MessageBoxIcon.Information);
				DialogResult = DialogResult.OK;
				Close();
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}

		}

		private void CancelButton_Click(object sender, EventArgs e)
		{
			DialogResult = DialogResult.Cancel;
			Close();
		}
	}
}
