﻿using SchoolScheduleContracts.BindingModels;
using SchoolScheduleContracts.BusinessLogicsContracts;
using SchoolScheduleContracts.SearchModels;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SchoolSchedule
{
	public partial class TeacherForm : Form
	{
		ITeacherLogic _logic;
		private int? _id;
		public int Id { set { _id = value; } }
		public TeacherForm(ITeacherLogic logic)
		{
			_logic = logic;
			InitializeComponent();
		}

		private void TeacherForm_Load(object sender, EventArgs e)
		{
			if (_id.HasValue)
			{
				try
				{
					var view = _logic.ReadElement(new TeacherSearchModel
					{
						Id =
				   _id.Value
					});
					if (view != null)
					{
						textBox1.Text = view.FullName;
					}
				}
				catch (Exception ex)
				{
					MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
					MessageBoxIcon.Error);
				}
			}
		}

		private void AddButton_Click(object sender, EventArgs e)
		{
			if (string.IsNullOrEmpty(textBox1.Text))
			{
				MessageBox.Show("Заполните название", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			try
			{
				var model = new TeacherBindingModel
				{
					Id = _id ?? 0,
					FullName = textBox1.Text
				};
				var operationResult = _id.HasValue ? _logic.Update(model) :
			   _logic.Create(model);
				if (!operationResult)
				{
					throw new Exception("Ошибка при сохранении.");
				}
				MessageBox.Show("Сохранение прошло успешно", "Сообщение",
			   MessageBoxButtons.OK, MessageBoxIcon.Information);
				DialogResult = DialogResult.OK;
				Close();
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}

		}

		private void CancelButton_Click(object sender, EventArgs e)
		{
			DialogResult = DialogResult.Cancel;
			Close();

		}
	}
}
