﻿using Microsoft.EntityFrameworkCore;
using SchoolScheduleContracts.BindingModels;
using SchoolScheduleContracts.SearchModels;
using SchoolScheduleContracts.StoragesContracts;
using SchoolScheduleContracts.ViewModels;
using SchoolScheduleDataBaseImplement.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace SchoolScheduleDataBaseImplement.Implements
{
	public class GradeStorage : IGradeStorage
	{
		public List<GradeViewModel> GetFullList()
		{
			using var context = new SchoolScheduleDataBase();
			return context.Grades.Include(x => x.Teacher)
			.Select(x => x.GetViewModel)
		   .ToList();
		}
		public List<GradeViewModel> GetFilteredList(GradeSearchModel model)
		{
			using var context = new SchoolScheduleDataBase();
			return context.Grades.Include(x => x.Teacher)
			.Where(x => (!model.Id.HasValue || x.Id == model.Id) && (!model.Letter.HasValue || x.Letter == model.Letter)
			&& (!model.Year.HasValue || x.Year == model.Year))
		   .Select(x => x.GetViewModel)
		   .ToList();
		}
		public GradeViewModel? GetElement(GradeSearchModel model)
		{
			if (!model.Id.HasValue && (!model.Letter.HasValue || !model.Year.HasValue))
			{
				return null;
			}
			using var context = new SchoolScheduleDataBase();
			return context.Grades.Include(x => x.Teacher)
			.FirstOrDefault(x =>
			(model.Id.HasValue && x.Id == model.Id) || (model.Letter.HasValue && model.Year.HasValue && x.Year == model.Year && x.Letter == model.Letter))
			?.GetViewModel;
		}
		public GradeViewModel? Insert(GradeBindingModel model)
		{
			using var context = new SchoolScheduleDataBase();
			var newComponent = Grade.Create(context, model);
			if (newComponent == null)
			{
				return null;
			}
			context.Grades.Add(newComponent);
			context.SaveChanges();
			return newComponent.GetViewModel;
		}
		public GradeViewModel? Update(GradeBindingModel model)
		{
			using var context = new SchoolScheduleDataBase();
			var component = context.Grades.FirstOrDefault(x => x.Id ==
		   model.Id);
			if (component == null)
			{
				return null;
			}
			component.Update(context, model);
			context.SaveChanges();
			return component.GetViewModel;
		}
		public GradeViewModel? Delete(GradeBindingModel model)
		{
			using var context = new SchoolScheduleDataBase();
			var element = context.Grades.FirstOrDefault(rec => rec.Id ==
		   model.Id);
			if (element != null)
			{
				context.Grades.Remove(element);
				context.SaveChanges();
				return element.GetViewModel;
			}
			return null;
		}
	}
}
